@@ -17,7 +17,7 @@
 invertGamma <- function(gam){
     N = length(gam)
     x = (0:(N-1))/(N-1)
-    gamI = approx(gam,x,xout=x)$y
+    gamI = stats::approx(gam,x,xout=x)$y
     gamI[N] = 1
     gamI = gamI/gamI[N]
     return(gamI)
